@@ -10,11 +10,10 @@ apt install appstream           \
             gnutls-dev          \
             libfwupd-dev        \
             libgpgme11-dev      \
-            libgtk-3-dev        \
+            libgtk-4-dev        \
             libgudev-1.0-dev    \
             libjson-glib-dev    \
-            libsoup2.4-dev      \
             libxmlb-dev         \
-            libhandy-1-dev      \
+            libadwaita-1-dev    \
             meson               \
             -yq
