@@ -7,6 +7,8 @@
 
 #include "config.h"
 
+#include <glib/gi18n.h>
+
 #include "gfu-common.h"
 
 /* formatting helper functions */
@@ -286,7 +288,7 @@ gfu_common_system_reboot(GError **error)
 
 /* GTK helper functions */
 
-gchar *
+const gchar *
 gfu_common_device_flags_to_string(guint64 device_flag)
 {
 	if (device_flag == FWUPD_DEVICE_FLAG_NONE) {
@@ -447,6 +449,36 @@ gfu_common_device_flags_to_string(guint64 device_flag)
 		 * typically a Windows NTFS partition with BitLocker */
 		return _("May invalidate secrets used to decrypt volumes");
 	}
+#endif
+#if FWUPD_CHECK_VERSION(1, 7, 5)
+	if (device_flag == FWUPD_DEVICE_FLAG_END_OF_LIFE) {
+		/* TRANSLATORS: the vendor is no longer supporting the device */
+		return _("End of life");
+	}
+#endif
+#if FWUPD_CHECK_VERSION(1, 7, 6)
+	if (device_flag == FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD) {
+		/* TRANSLATORS: firmware is verified on-device the payload using strong crypto */
+		return _("Signed payload");
+	}
+#endif
+#if FWUPD_CHECK_VERSION(1, 7, 6)
+	if (device_flag == FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD) {
+		/* TRANSLATORS: firmware payload is unsigned and it is possible to modify it */
+		return _("Unsigned payload");
+	}
+#endif
+#if FWUPD_CHECK_VERSION(1, 8, 11)
+	if (device_flag == FWUPD_DEVICE_FLAG_EMULATED) {
+		/* TRANSLATORS: this device is not actually real */
+		return _("Emulated");
+	}
+#endif
+#if FWUPD_CHECK_VERSION(1, 8, 11)
+	if (device_flag == FWUPD_DEVICE_FLAG_EMULATION_TAG) {
+		/* TRANSLATORS: we're saving all USB events for emulation */
+		return _("Tagged for emulation");
+	}
 #endif
 	if (device_flag == FWUPD_DEVICE_FLAG_UNKNOWN) {
 		return NULL;
@@ -454,7 +486,7 @@ gfu_common_device_flags_to_string(guint64 device_flag)
 	return NULL;
 }
 
-gchar *
+const gchar *
 gfu_common_device_icon_from_flag(FwupdDeviceFlags device_flag)
 {
 	if (device_flag == FWUPD_DEVICE_FLAG_INTERNAL)
@@ -468,7 +500,7 @@ gfu_common_device_icon_from_flag(FwupdDeviceFlags device_flag)
 	if (device_flag == FWUPD_DEVICE_FLAG_LOCKED)
 		return "locked-symbolic";
 	if (device_flag == FWUPD_DEVICE_FLAG_SUPPORTED)
-		return "security-high-symbolic";
+		return "network-transmit-receive-symbolic";
 	if (device_flag == FWUPD_DEVICE_FLAG_NEEDS_BOOTLOADER)
 		return "computer-symbolic";
 	if (device_flag == FWUPD_DEVICE_FLAG_NEEDS_REBOOT)
@@ -530,6 +562,26 @@ gfu_common_device_icon_from_flag(FwupdDeviceFlags device_flag)
 #if FWUPD_CHECK_VERSION(1, 7, 1)
 	if (device_flag == FWUPD_DEVICE_FLAG_AFFECTS_FDE)
 		return "system-lock-screen-symbolic";
+#endif
+#if FWUPD_CHECK_VERSION(1, 7, 5)
+	if (device_flag == FWUPD_DEVICE_FLAG_END_OF_LIFE)
+		return "alarm-symbolic";
+#endif
+#if FWUPD_CHECK_VERSION(1, 7, 6)
+	if (device_flag == FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD)
+		return "security-high-symbolic";
+#endif
+#if FWUPD_CHECK_VERSION(1, 7, 6)
+	if (device_flag == FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD)
+		return "security-low-symbolic";
+#endif
+#if FWUPD_CHECK_VERSION(1, 8, 11)
+	if (device_flag == FWUPD_DEVICE_FLAG_EMULATED)
+		return "media-playlist-repeat-symbolic";
+#endif
+#if FWUPD_CHECK_VERSION(1, 8, 11)
+	if (device_flag == FWUPD_DEVICE_FLAG_EMULATION_TAG)
+		return "media-playlist-repeat-song-symbolic";
 #endif
 	if (device_flag == FWUPD_DEVICE_FLAG_UNKNOWN)
 		return "unknown-symbolic";
