@@ -7,14 +7,13 @@
 #include "config.h"
 
 #include <adwaita.h>
-#include <fwupd.h>
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
 #include <gtk/gtk.h>
 #include <locale.h>
 #include <stdlib.h>
 
-#include "gfu-common.c"
+#include "gfu-common.h"
 #include "gfu-device-row.h"
 #include "gfu-release-row.h"
 
@@ -199,7 +198,7 @@ gfu_main_set_device_flags(GfuMain *self, guint64 flags)
 
 	/* iterate through flags */
 	for (guint j = 0; j < 64; j++) {
-		gchar *flag_tmp;
+		const gchar *flag_tmp;
 		/* if flag is not set, skip */
 		if ((flags & ((guint64)1 << j)) == 0)
 			continue;
@@ -280,7 +279,7 @@ gfu_main_device_problem_to_string(GfuMain *self, FwupdDeviceProblem problem)
 		    fwupd_device_get_battery_threshold(self->device) ==
 			FWUPD_BATTERY_LEVEL_INVALID) {
 			/* TRANSLATORS: for example the batteries *inside* the Bluetooth mouse */
-			return g_strdup_printf(_("Device battery power is too low"));
+			return g_strdup(_("Device battery power is too low"));
 		}
 		/* TRANSLATORS: for example the batteries *inside* the Bluetooth mouse */
 		return g_strdup_printf(_("Device battery power is too low (%u%%, requires %u%%)"),
@@ -348,7 +347,6 @@ gfu_main_refresh_device_cb(gpointer user_data)
 	g_autofree gchar *problems_str = NULL;
 	g_autoptr(GString) attr = g_string_new(NULL);
 	g_autoptr(GString) version = NULL;
-	g_autoptr(GError) error = NULL;
 
 	/* set stack */
 	w = GTK_WIDGET(gtk_builder_get_object(self->builder, "stack_main"));
@@ -1010,7 +1008,8 @@ gfu_main_install_release_cb(GObject *source, GAsyncResult *res, gpointer user_da
 		    /* TRANSLATORS: prompting a shutdown to the user */
 		    _("The update requires the system to shutdown to complete."));
 		gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog),
-							 "Shutdown now?");
+							 "%s",
+							 _("Shutdown now?"));
 		g_signal_connect(dialog,
 				 "response",
 				 G_CALLBACK(gfu_main_reboot_shutdown_response_cb),
@@ -1025,7 +1024,8 @@ gfu_main_install_release_cb(GObject *source, GAsyncResult *res, gpointer user_da
 						/* TRANSLATORS: prompting a reboot to the user */
 						_("The update requires a reboot to complete."));
 		gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog),
-							 "Restart now?");
+							 "%s",
+							 _("Restart now?"));
 		g_signal_connect(dialog,
 				 "response",
 				 G_CALLBACK(gfu_main_reboot_restart_response_cb),
@@ -1136,11 +1136,11 @@ gfu_main_release_show_branch_warning(GfuMain *self)
 					 "with %s."),
 				       fwupd_device_get_vendor(self->device));
 	} else {
-		g_string_append_printf(body,
-				       /* TRANSLATORS: the vendor is unknown */
-				       _("Your hardware may be damaged using this firmware, "
-					 "and installing this release may void any warranty "
-					 "with the vendor."));
+		g_string_append(body,
+				/* TRANSLATORS: the vendor is unknown */
+				_("Your hardware may be damaged using this firmware, "
+				  "and installing this release may void any warranty "
+				  "with the vendor."));
 	}
 	g_string_append(body, "\n\n");
 	g_string_append(body,
@@ -1206,11 +1206,13 @@ gfu_main_release_show_confirmation(GfuMain *self)
 	if (fwupd_device_has_flag(self->device, FWUPD_DEVICE_FLAG_USABLE_DURING_UPDATE)) {
 		gtk_message_dialog_format_secondary_text(
 		    GTK_MESSAGE_DIALOG(dialog),
+		    "%s",
 		    /* TRANSLATORS: the device can be used normallly */
 		    _("The device will remain usable for the duration of the update"));
 	} else {
 		gtk_message_dialog_format_secondary_text(
 		    GTK_MESSAGE_DIALOG(dialog),
+		    "%s",
 		    /* TRANSLATORS: the device will be non-fuctional for a while */
 		    _("The device will be unusable while the update is installing"));
 	}
@@ -1337,6 +1339,7 @@ gfu_main_device_verify_clicked_cb(GtkWidget *widget, GfuMain *self)
 					_("Verify firmware checksums?"));
 	gtk_message_dialog_format_secondary_text(
 	    GTK_MESSAGE_DIALOG(dialog),
+	    "%s",
 	    /* TRANSLATORS: device will "go away" and then "come back" */
 	    _("The device may be unusable during this action"));
 	g_signal_connect(dialog, "response", G_CALLBACK(gfu_main_device_verify_response_cb), self);
@@ -1385,6 +1388,7 @@ gfu_main_device_verify_update_cb(GtkWidget *widget, GfuMain *self)
 					_("Update cryptographic hash"));
 	gtk_message_dialog_format_secondary_text(
 	    GTK_MESSAGE_DIALOG(dialog),
+	    "%s",
 	    /* TRANSLATORS: save what we have now as "valid" */
 	    _("Record current device cryptographic hashes as verified?"));
 	g_signal_connect(dialog,
@@ -1452,7 +1456,6 @@ gfu_main_refresh_release(GfuMain *self)
 	GPtrArray *checks = NULL;
 	GPtrArray *issues = NULL;
 	g_autofree gchar *desc = NULL;
-	g_autoptr(GString) size = g_string_new(NULL);
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GString) attr = g_string_new(NULL);
 
@@ -1680,7 +1683,8 @@ gfu_main_unlock_cb(GObject *source, GAsyncResult *res, gpointer user_data)
 		    /* TRANSLATORS: prompting a shutdown to the user */
 		    _("Unlocking a device requires the system to shutdown to complete."));
 		gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog),
-							 "Shutdown now?");
+							 "%s",
+							 _("Shutdown now?"));
 		g_signal_connect(dialog,
 				 "response",
 				 G_CALLBACK(gfu_main_reboot_shutdown_response_cb),
@@ -1696,6 +1700,7 @@ gfu_main_unlock_cb(GObject *source, GAsyncResult *res, gpointer user_data)
 					   /* TRANSLATORS: prompting a reboot to the user */
 					   _("Unlocking a device requires a reboot to complete."));
 		gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog),
+							 "%s",
 							 /* TRANSLATORS: button text */
 							 _("Restart now?"));
 		g_signal_connect(dialog,
@@ -1755,6 +1760,9 @@ gfu_main_client_connect_cb(GObject *source, GAsyncResult *res, gpointer user_dat
 		return;
 	}
 
+	/* set user agent */
+	fwupd_client_set_user_agent_for_package(self->client, GETTEXT_PACKAGE, VERSION);
+
 	/* get data */
 	fwupd_client_set_feature_flags_async(
 	    self->client,
@@ -1773,9 +1781,6 @@ gfu_main_startup_cb(GApplication *application, GfuMain *self)
 {
 	GtkWidget *w;
 	GtkWidget *main_window;
-	g_autofree gchar *filename = NULL;
-	g_autoptr(GError) error = NULL;
-	g_autoptr(GPtrArray) devices = NULL;
 
 	/* add application menu items */
 	g_action_map_add_action_entries(G_ACTION_MAP(application),
@@ -1927,7 +1932,6 @@ main(int argc, char **argv)
 
 	self->cancellable = g_cancellable_new();
 	self->client = fwupd_client_new();
-	fwupd_client_set_user_agent_for_package(self->client, GETTEXT_PACKAGE, VERSION);
 	g_signal_connect(self->client,
 			 "notify::percentage",
 			 G_CALLBACK(gfu_main_client_percentage_changed_cb),
@@ -1955,7 +1959,11 @@ main(int argc, char **argv)
 	self->post_requests = g_ptr_array_new_with_free_func((GDestroyNotify)g_object_unref);
 
 	/* ensure single instance */
+#if GLIB_CHECK_VERSION(2, 74, 0)
+	self->application = adw_application_new("org.gnome.Firmware", G_APPLICATION_DEFAULT_FLAGS);
+#else
 	self->application = adw_application_new("org.gnome.Firmware", G_APPLICATION_FLAGS_NONE);
+#endif
 	g_signal_connect(self->application, "startup", G_CALLBACK(gfu_main_startup_cb), self);
 	g_signal_connect(self->application, "activate", G_CALLBACK(gfu_main_activate_cb), self);
 	/* set verbose? */
