@@ -11,6 +11,7 @@
 #include "gfu-release-row.h"
 
 typedef struct {
+	FwupdDevice *device;
 	FwupdRelease *release;
 	GtkWidget *image;
 	GtkWidget *name;
@@ -62,6 +63,18 @@ gfu_release_row_refresh(GfuReleaseRow *self)
 		 * currently installed */
 		gtk_button_set_label(GTK_BUTTON(priv->button), _("Reinstall"));
 	}
+
+	/* only mark active if updatable; there might be a problem */
+	if (fwupd_device_has_flag(priv->device, FWUPD_DEVICE_FLAG_UPDATABLE)) {
+		gtk_widget_set_tooltip_text(priv->button, NULL);
+		gtk_widget_set_sensitive(priv->button, TRUE);
+	} else {
+		gtk_widget_set_tooltip_text(
+		    priv->button,
+		    /* TRANSLATORS: problems are things the user has to fix, e.g. low battery */
+		    _("Cannot perform action as the device has a problem"));
+		gtk_widget_set_sensitive(priv->button, FALSE);
+	}
 }
 
 FwupdRelease *
@@ -108,6 +121,18 @@ gfu_release_row_set_release(GfuReleaseRow *self, FwupdRelease *release)
 	gfu_release_row_refresh(self);
 }
 
+static void
+gfu_release_row_set_device(GfuReleaseRow *self, FwupdDevice *device)
+{
+	GfuReleaseRowPrivate *priv = gfu_release_row_get_instance_private(self);
+	priv->device = g_object_ref(device);
+	g_signal_connect_object(priv->device,
+				"notify::flags",
+				G_CALLBACK(gfu_release_row_notify_props_changed_cb),
+				self,
+				0);
+}
+
 static void
 gfu_release_row_dispose(GObject *object)
 {
@@ -119,6 +144,7 @@ gfu_release_row_dispose(GObject *object)
 						     gfu_release_row_notify_props_changed_cb,
 						     self);
 
+	g_clear_object(&priv->device);
 	g_clear_object(&priv->release);
 	if (priv->pending_refresh_id != 0) {
 		g_source_remove(priv->pending_refresh_id);
@@ -174,11 +200,12 @@ gfu_release_row_init(GfuReleaseRow *self)
 }
 
 GtkWidget *
-gfu_release_row_new(FwupdRelease *release)
+gfu_release_row_new(FwupdDevice *device, FwupdRelease *release)
 {
 	GtkWidget *self;
 	g_return_val_if_fail(FWUPD_IS_RELEASE(release), NULL);
 	self = g_object_new(GFU_TYPE_RELEASE_ROW, NULL);
+	gfu_release_row_set_device(GFU_RELEASE_ROW(self), device);
 	gfu_release_row_set_release(GFU_RELEASE_ROW(self), release);
 	return self;
 }
