@@ -21,7 +21,7 @@ struct _GfuReleaseRowClass {
 };
 
 GtkWidget *
-gfu_release_row_new(FwupdRelease *release);
+gfu_release_row_new(FwupdDevice *device, FwupdRelease *release);
 FwupdRelease *
 gfu_release_row_get_release(GfuReleaseRow *self);
 
